parse

Function parse 

pub fn parse(input: &str) -> Option<NaiveDate>
Returns a date on successful parsing with defaults applied:

  1. Week starts with Monday,
  2. Calls for chrono::Local::now,
  3. next and last mean the closest but today, e. g. next Wednesday will mean tomorrow if today is Tuesday.